@@ -21,15 +21,16 @@ class ROIImageViewModule(ImageViewModule):
         self.click_event = False
         self.outlines = True
         self.trial_selector_input = OptionInput(
-            "Trial:", "", self.set_background,
+            "Time Block:", "", self.set_background,
             val_list=self.data_handler.trials_loaded,
-            tool_tip="Select Trial to display",
+            tool_tip="Select Time block  to display",
             display_tool_tip=False, default_index=0,
             show_name=True)
         self.set_background("", "Max Image", update_image=False)
         self.image_item.mouseClickEvent = lambda x: self.roi_view_click(x)
         self.image_item.mouseDragEvent = lambda x: self.roi_view_drag(x)
 
+
         shape = main_widget.data_handler.shape
         self.select_image_flat = np.zeros([shape[0] * shape[1], 3])
         self.box_selector_enabled = False
@@ -123,7 +124,8 @@ class ROIImageViewModule(ImageViewModule):
 
     def set_background(self, name, func_name, update_image=True, reset_override=False):
         if (not self.resetting_view or reset_override):
-            self.main_widget.console.updateText("Setting current background to: %s"%func_name)
+            self.main_widget.console.updateText(
+                "Setting current background to: %s" % func_name)
             # Background refers to the image behind the rois
             shape = self.main_widget.data_handler.shape
             if func_name == "Mean Image":
@@ -153,14 +155,20 @@ class ROIImageViewModule(ImageViewModule):
                     self.current_background_name = "Eigen Norm Image"
                 except AttributeError:
                     print("Eigen vectors aren't currently generated or valid")
-                    self.main_widget.console.updateText("Can't display EigenNorm image, Eigen vectors aren't currently generated or valid")
+
 
                     self.current_background = self.main_widget.data_handler.max_images[
                                                   self.data_handler.trials_loaded.index(
                                                       self.trial_selector_input.current_state())][
                                               :].reshape(
                         [-1, 1])
+                    if update_image:
+                        self.updateImageDisplay()
+                    self.main_widget.console.updateText(
+                        "Can't display Eigen Norm image, Eigen vectors aren't currently generated or valid")
+
                     self.current_background_name = "Max Image"
+                    return
             else:
                 self.current_background_name = "Max Image"
                 try:
@@ -271,7 +279,8 @@ class ROIImageViewModule(ImageViewModule):
         except AttributeError:
             pass
         except IndexError:
-            self.main_widget.console.updateText("Please regenerate ROIs before trying this operation")
+            self.main_widget.console.updateText(
+                "Please regenerate ROIs before trying this operation")
 
             print("Please regenerate ROIs before trying this operation")
         except ValueError as e:
