@@ -75,17 +75,26 @@ class ROIExtractionTab(Tab):
         roi_modification_button_top_widget.setLayout(roi_modification_button_top_layout)
         # roi_modification_tab_layout.addLayout(roi_modification_button_top_layout)
 
-        add_new_roi = QPushButton(text="Create ROI from\nSelection (D)")
+        add_new_roi = QPushButton(text="Create ROI from\nMask (D)")
         add_new_roi.clicked.connect(lambda x: self.add_new_roi())
-        add_to_roi = QPushButton(text="Add to Selected\nROI (A)")
+        add_new_roi.setToolTip("Use this button to create a new ROI from mask. \n"
+                               "ROI is added to bottiom of ROI list")
+        add_to_roi = QPushButton(text="Add Mask to Selected\nROI (A)")
         add_to_roi.clicked.connect(
             lambda x: self.modify_roi(self.roi_list_module.current_selected_roi, "add"))
-
-        sub_to_roi = QPushButton(text="Subtract from\nSelected ROI (S)")
+        add_to_roi.setToolTip("Use this button to add the current mask to"
+                              " the selected ROI. \n"
+                              "Select an roi in the ROI list below")
+        sub_to_roi = QPushButton(text="Subtract Mask from\nSelected ROI (S)")
         sub_to_roi.clicked.connect(
             lambda x: self.modify_roi(self.roi_list_module.current_selected_roi,
                                       "subtract"))
+        sub_to_roi.setToolTip("Use this button to subtract the current mask from"
+                              " the selected ROI. \n"
+                              "Select an roi in the ROI list below")
         delete_roi = QPushButton(text="Delete Selected\nROI (F)")
+        delete_roi.setToolTip("Use this button to delete the selected ROI. \n"
+                              "Select an roi in the ROI list below")
         delete_roi.clicked.connect(
             lambda x: self.delete_roi(self.roi_list_module.current_selected_roi))
 
@@ -102,9 +111,17 @@ class ROIExtractionTab(Tab):
         painter_button_group = QButtonGroup()
         self.off_button = QRadioButton(text="Off (Q)")
         self.off_button.setChecked(True)
-        self.on_button = QRadioButton(text="Add to Selection (W)")
-        self.sub_button = QRadioButton(text="Subtract from Selection (E)")
+        self.off_button.setToolTip("Turns off the mask brush")
+        self.on_button = QRadioButton(text="Add to Mask (W)")
+        self.on_button.setToolTip(
+            "Turns on the selector brush, draw on the image by right clicking")
+        self.sub_button = QRadioButton(text="Subtract from Mask (E)")
+        self.sub_button.setToolTip(
+            "Turns the selector brush to subtract mode. Removing currently selected pixels")
         self.magic_wand = QRadioButton(text="Magic Wand (R)")
+        self.magic_wand.setToolTip(
+            "Turns the Mask brush to magic wand mode. Click on where you believe \n"
+            "there should be an ROI, and it will attempt to create one for you.\n Note just click one at a time. ")
         self.off_button.setStyleSheet("QWidget {border: 0px solid #32414B;}")
         self.on_button.setStyleSheet("QWidget {border: 0px solid #32414B;}")
         self.sub_button.setStyleSheet("QWidget {border: 0px solid #32414B;}")
@@ -125,7 +142,7 @@ class ROIExtractionTab(Tab):
 
         painter_layout = QVBoxLayout()
         painter_widget.setLayout(painter_layout)
-        label = QLabel(text="Selector Brush: ")
+        label = QLabel(text="Mask Brush: ")
         label.setStyleSheet("QWidget {border: 0px solid #32414B;}")
         painter_layout.addWidget(label)
 
@@ -144,7 +161,7 @@ class ROIExtractionTab(Tab):
                                                 "35"])
         self._brush_size_options.setStyleSheet("QWidget {border: 0px solid #32414B;}")
         painter_layout.addWidget(self._brush_size_options)
-        clear_from_selection = QPushButton(text="Clear Selection (T)")
+        clear_from_selection = QPushButton(text="Clear Mask (T)")
         clear_from_selection.setStyleSheet("QWidget {border: 0px solid #32414B;}")
         clear_from_selection.clicked.connect(
             lambda x: self.image_view.clearPixelSelection())
@@ -216,7 +233,8 @@ class ROIExtractionTab(Tab):
         self.time_trace_type = OptionInput("Time Trace Type", "",
                                            lambda x, y: x + y,
                                            default_index=0,
-                                           tool_tip="Select way to calculate time trace",
+                                           tool_tip="Select way to calculate time trace,"
+                                                    " \ncheck github for more details",
                                            val_list=["Mean Florescence Denoised",
                                                      "Mean Florescence",
                                                      "DeltaF Over F Denoised",
@@ -245,40 +263,41 @@ class ROIExtractionTab(Tab):
 
     def keyPressEvent(self, event):
         super(ROIExtractionTab, self).keyPressEvent(event)
-        if event.key() == 81: # Q
-            self.off_button.setChecked(True)
-            self.image_view.setSelectorBrushType("off")
-        if event.key() == 87: # W
-            if self.on_button.isChecked():
+        if self.tab_selector_roi.currentIndex() == 1:
+            if event.key() == 81:  # Q
                 self.off_button.setChecked(True)
                 self.image_view.setSelectorBrushType("off")
-            else:
-                self.on_button.setChecked(True)
-                self.image_view.setSelectorBrushType("add")
-        if event.key() == 69: # E
-            if self.sub_button.isChecked():
-                self.off_button.setChecked(True)
-                self.image_view.setSelectorBrushType("off")
-            else:
-                self.sub_button.setChecked(True)
-                self.image_view.setSelectorBrushType("subtract")
-        if event.key() == 82: # R
-            if self.magic_wand.isChecked():
-                self.off_button.setChecked(True)
-                self.image_view.setSelectorBrushType("off")
-            else:
-                self.magic_wand.setChecked(True)
-                self.image_view.setSelectorBrushType("magic")
-        if event.key() == 84: # T
-            self.image_view.clearPixelSelection()
-        if event.key() == 65: #A
-            self.modify_roi(self.roi_list_module.current_selected_roi, "add")
-        if event.key() == 83:
-            self.modify_roi(self.roi_list_module.current_selected_roi, "subtract")
-        if event.key() == 68:
-            self.add_new_roi()
-        if event.key() == 70:
-            self.delete_roi(self.roi_list_module.current_selected_roi)
+            if event.key() == 87:  # W
+                if self.on_button.isChecked():
+                    self.off_button.setChecked(True)
+                    self.image_view.setSelectorBrushType("off")
+                else:
+                    self.on_button.setChecked(True)
+                    self.image_view.setSelectorBrushType("add")
+            if event.key() == 69:  # E
+                if self.sub_button.isChecked():
+                    self.off_button.setChecked(True)
+                    self.image_view.setSelectorBrushType("off")
+                else:
+                    self.sub_button.setChecked(True)
+                    self.image_view.setSelectorBrushType("subtract")
+            if event.key() == 82:  # R
+                if self.magic_wand.isChecked():
+                    self.off_button.setChecked(True)
+                    self.image_view.setSelectorBrushType("off")
+                else:
+                    self.magic_wand.setChecked(True)
+                    self.image_view.setSelectorBrushType("magic")
+            if event.key() == 84:  # T
+                self.image_view.clearPixelSelection()
+            if event.key() == 65:  # A
+                self.modify_roi(self.roi_list_module.current_selected_roi, "add")
+            if event.key() == 83:  #S
+                self.modify_roi(self.roi_list_module.current_selected_roi, "subtract")
+            if event.key() == 68:  # D
+                self.add_new_roi()  #F
+            if event.key() == 70:
+                self.delete_roi(self.roi_list_module.current_selected_roi)
 
     @property
     def data_handler(self):
@@ -347,13 +366,13 @@ class ROIExtractionTab(Tab):
         """
         if (self.main_widget.checkThreadRunning()):
 
-            if roi_num is None or roi_num<1:
+            if roi_num is None or roi_num <1:
                 self.main_widget.console.updateText("Invalid ROI Selected")
                 print("Invalid ROI Selected")
                 return
             roi_num = roi_num - 1
             try:
-                self.main_widget.console.updateText("Deleting ROI #%s"%str(roi_num+1))
+                self.main_widget.console.updateText("Deleting ROI #%s" % str(roi_num + 1))
                 self.data_handler.rois.pop(roi_num)
                 self.data_handler.gen_roi_display_variables()
                 self.data_handler.time_traces.pop(roi_num)
@@ -393,8 +412,10 @@ class ROIExtractionTab(Tab):
                 temp_roi = combine_rois(
                     self.data_handler.rois[roi_num],
                     self.image_view.current_selected_pixels_list)
-                num= number_connected_components(self.data_handler.shape[0]*self.data_handler.shape[1], [0]+self.data_handler.shape,temp_roi)
-                if num== 2 or override:
+                num = number_connected_components(
+                    self.data_handler.shape[0] * self.data_handler.shape[1],
+                    [0] + self.data_handler.shape, temp_roi)
+                if num == 2 or override:
 
                     self.data_handler.rois[roi_num] = temp_roi
                     self.data_handler.gen_roi_display_variables()
@@ -404,13 +425,15 @@ class ROIExtractionTab(Tab):
                     msg.setIcon(QMessageBox.Information)
                     msg.setStyleSheet(qdarkstyle.load_stylesheet())
 
-                    msg.setText("The pixels you selected are not connect to ROI #%s, Are you sure you want to add them?" % str(roi_num+1))
+                    msg.setText(
+                        "The pixels you selected are not connect to ROI #%s, Are you sure you want to add them?" % str(
+                            roi_num + 1))
                     # msg.setInformativeText("This is additional information")
                     # msg.setWindowTitle("MessageBox demo")
                     # msg.setDetailedText("The details are as follows:")
                     msg.setStandardButtons(QMessageBox.Ok | QMessageBox.Cancel)
                     retval = msg.exec_()
-                    if retval==1024:
+                    if retval == 1024:
                         self.data_handler.rois[roi_num] = temp_roi
                         self.data_handler.gen_roi_display_variables()
                         self.data_handler.calculate_time_trace(roi_num)
@@ -431,10 +454,12 @@ class ROIExtractionTab(Tab):
             self.off_button.setChecked(True)
             self.image_view.setSelectorBrushType("off")
             self.update_roi(new=False)
-            if add_subtract=="subtract":
-                self.main_widget.console.updateText("Subtracting Selection from ROI #" + str(roi_num + 1))
+            self.main_widget.tabs[2].updateTab()
+            if add_subtract == "subtract":
+                self.main_widget.console.updateText(
+                    "Subtracting Selection from ROI #" + str(roi_num + 1))
 
-            if add_subtract=="add":
+            if add_subtract == "add":
                 self.main_widget.console.updateText(
                     "Adding Selection to ROI #" + str(roi_num + 1))
             return True
