@@ -35,6 +35,10 @@ def load_filter_tif_stack(*, path, filter: bool, median_filter: bool,
 
     """
     size = [0, 0]
+    # image = np.zeros((50,100,100), np.float32)
+    # for x in range(25):
+    #     image[x*2,:,0::10] = 255
+    # return [100,100], image.transpose((0,2,1))
     if os.path.isdir(path):
         volumes = []
         paths = path if type(path) == list else sorted(os.listdir(path))
@@ -92,6 +96,8 @@ def load_filter_tif_stack(*, path, filter: bool, median_filter: bool,
                         :, :]
             if not trial_split and crop_stack:
                 image = z1[:, crop_x[0]:crop_x[1], crop_y[0]:crop_y[1]]
+            if not trial_split and not crop_stack:
+                image= z1[:]
             if len(image.shape) == 2:
                 image = image.reshape((1, image.shape[0], image.shape[1]))
             if slice_stack:
@@ -158,8 +164,7 @@ def save_image(volume: np.ndarray, name: str, directory: str, shape: tuple,
 def filter_stack(*, stack: np.ndarray, median_filter: bool,
                  median_filter_size: Tuple[int, int, int],
                  z_score: bool, hist_eq=False, localSpatialDenoising=False):
-    if localSpatialDenoising:
-        stack = applyLocalSpatialDenoising(stack)
+
 
         # stack = ndimage.filters.convolve(stack, np.full((3, 3, 3), 1.0 / 27))
     if z_score and not hist_eq:
@@ -187,6 +192,8 @@ def filter_stack(*, stack: np.ndarray, median_filter: bool,
         stack_equalized_filtered = ndimage.median_filter(stack_equalized_squared,
                                                          (1, 1, 3))
         stack = np.transpose(stack_equalized_filtered, (2, 0, 1))
+        if localSpatialDenoising:
+            stack = applyLocalSpatialDenoising(stack)
     if median_filter:
         stack = ndimage.median_filter(stack, median_filter_size)
     return stack
